const PDFDocument = require("pdfkit");
const fs = require("fs");

/**
 * Generates a styled employee report PDF
 * @param {Object} data - Report data
 * @param {string} outputPath - File path to save PDF
 */
function generateReport(data, outputPath) {
  const doc = new PDFDocument({ margin: 50 });

  doc.pipe(fs.createWriteStream(outputPath));

  // 🔵 Header Banner
  doc
    .rect(0, 0, doc.page.width, 60)
    .fill("#007ACC")
    .fillColor("white")
    .fontSize(24)
    .text("Employee Report", 50, 20, { align: "left" });

  doc.moveDown(2).fillColor("black");

  // 🔹 Employee Info
  doc
    .fontSize(14)
    .text("Name: ", { continued: true })
    .font("Helvetica-Bold")
    .text(`${data.name}`)
    .font("Helvetica")
    .text(`Department: ${data.department}`)
    .text(`Date: ${new Date().toLocaleDateString()}`)
    .moveDown();

  // 📊 Attendance Section
  doc
    .fontSize(16)
    .fillColor("#333")
    .text("Attendance Summary", { underline: true })
    .moveDown(0.5)
    .fontSize(12)
    .list([
      `Total Days: ${data.attendance.totalDays}`,
      `Present: ${data.attendance.present}`,
      `Absent: ${data.attendance.absent}`,
      `Half Days: ${data.attendance.halfDays}`,
    ])
    .moveDown();

  // 📝 Leave Section
  doc
    .fontSize(16)
    .text("Leave Summary", { underline: true })
    .moveDown(0.5)
    .fontSize(12)
    .list([
      `Total Leaves: ${data.leave.total}`,
      `Approved: ${data.leave.approved}`,
      `Rejected: ${data.leave.rejected}`,
    ])
    .moveDown();

  doc.end();
}

module.exports = generateReport;
